@@ -284,7 +284,7 @@ def MO(root,screen,logfile,start,end,useold,COOP,FWHM,makeorigin,gnuplotexec):
                     for j in range(len(groupname)):
                         line=line+"\t"+str(orb_MPA[i][j])
                 if unres:
-                    line=line+"\t"+str(i+1)+"\t"+nameorb(HOMO_beta,i)+"\t"+str(round(evalue_beta[i],2))+"\t"+symmetry[i]
+                    line=line+"\t"+str(i+1)+"\t"+nameorb(HOMO_beta,i)+"\t"+str(round(evalue_beta[i],2))+"\t"+symmetry_beta[i]
                     if groups and overlapmatrix and pop:
                         for j in range(len(groupname)):
                             line=line+"\t"+str(int(orb_MPA_beta[i][j]*100+.5))
